@@ -2,8 +2,7 @@ from .imports import *
 
 to_exclude = list(globals().keys())
 
-from .low_level import *
-from .high_level import *
+from .training import *
 from .utils import *
 
 for key in to_exclude:
